# -*- coding: utf-8 -*-
### BEGIN LICENSE
# Busca: Full featured file searching application
# Copyright (C) 2009 Jordi Carrillo Bosch
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

### END LICENSE

import sys
import os
import gtk
import logging
import pprint
from desktopcouch.records.server import CouchDatabase
from desktopcouch.records.record import Record

from busca.buscaconfig import getdatapath

class BuscaPreferencesDialog(gtk.Dialog):
    __gtype_name__ = "BuscaPreferencesDialog"
    preferences = {}

    def __init__(self):
        """__init__ - This function is typically not called directly.
        Creation of a PreferencesFindfilesDialog requires redeading the associated ui
        file and parsing the ui definition extrenally,
        and then calling PreferencesFindfilesDialog.finish_initializing().

        Use the convenience function NewPreferencesFindfilesDialog to create
        NewAboutFindfilesDialog objects.
        """
        self.logger = logging.getLogger('buscapreferences')
        self.searchHidden = False
        self.recurseDirs = False
        self.reportDuplicated = False

    #@property
    #def searchHidden(self):
        #return self.searchHidden

    #@property
    #def recurseDirs(self):
        #return self.recurseDirs


    def finish_initializing(self, builder):
        """finish_initalizing should be called after parsing the ui definition
        and creating a AboutFindfilesDialog object with it in order to finish
        initializing the start of the new AboutFindfilesDialog instance.
        """

        #get a reference to the builder and set up the signals
        self.builder = builder
        self.builder.connect_signals(self)

        #set up couchdb and the preference info
        self.__db_name = "busca"
        self.__database = CouchDatabase(self.__db_name, create=True)
        self.chkdSearchHidden = builder.get_object('chkdSearchHidden')
        self.chkdRecurseDirs = builder.get_object('chkdRecurseDirs')
        self.chkdReportDuplicated = builder.get_object('chkdReportDuplicated')
        self.__preferences = None
        self.__key = None

        #set the record type and then initalize the preferences
        self.__record_type = "http://wiki.ubuntu.com/Quickly/RecordTypes/Busca/Preferences"
        self.__preferences = self.get_preferences()
        #TODO:code for other initialization actions should be added here
    
    
    def on_chkdSearchHidden_toggled(self, widget):
        self.searchHidden = self.chkdSearchHidden.get_active()
    
    def on_chkdRecurseDirs_toggled(self, widget):
        self.recurseDirs = self.chkdRecurseDirs.get_active()

    def on_chkdReportDuplicated_toggled(self, widget):
        self.reportDuplicated = self.chkdReportDuplicated.get_active()

    def get_preferences(self):
        """get_preferences  -returns a dictionary object that contain
        preferences for findfiles. Creates a couchdb record if
        necessary.
        """

        if self.__preferences == None: #the dialog is initializing
            self.__load_preferences()
        
        return self.__preferences

    def __load_preferences(self):
        #TODO: add preferences to the self.__preferences dict
        #default preferences that will be overwritten if some are saved
        self.__preferences = {"record_type" : self.__record_type,
                              "chkdSearchHidden" : self.searchHidden,
                              "chkdRecurseDirs" : self.recurseDirs,
                              "chkdReportDuplicated" : self.reportDuplicated}
        
        results = self.__database.get_records(record_type=self.__record_type, create_view=True)
        self.logger.debug("load preferences results [%s]" % results)

        for result in results:
            record = result.value
            self.searchHidden = record['chkdSearchHidden']
            self.recurseDirs = record['chkdRecurseDirs']
            self.reportDuplicated = record['chkdReportDuplicated']
            self.__preferences['chkdSearchHidden'] = self.searchHidden
            self.__preferences['chkdRecurseDirs'] = self.recurseDirs
            self.__preferences['chkdReportDuplicated'] = self.reportDuplicated
            self.logger.debug('searchHidden [%s] recurseDirs [%s] reportDuplicated [%s]' %
                    (self.searchHidden, self.recurseDirs, self.reportDuplicated))
            self.chkdSearchHidden.set_active(self.searchHidden)
            self.chkdRecurseDirs.set_active(self.recurseDirs)
            self.chkdReportDuplicated.set_active(self.reportDuplicated)
            return 

        self.__key = self.__database.put_record(Record(self.__preferences))
        
    def __save_preferences(self):
        self.searchHidden = self.chkdSearchHidden.get_active()
        self.recurseDirs = self.chkdRecurseDirs.get_active()

        results = self.__database.get_records(record_type=self.__record_type, create_view=True)
        self.logger.debug("load preferences results [%s]" % results)

        for result in results:
            record = result.value
            key = record["_id"]
            self.__database.update_fields(key, {"chkdRecurseDirs" : self.recurseDirs,
                                                "chkdSearchHidden" : self.searchHidden,
                                                "chkdReportDuplicated" : self.reportDuplicated})
            return


    def ok(self, widget, data=None):
        """ok - The user has elected to save the changes.
        Called before the dialog returns gtk.RESONSE_OK from run().
        """

        #make any updates to self.__preferences here
        #self.__preferences["preference1"] = "value2"
        self.__save_preferences()

    def cancel(self, widget, data=None):
        """cancel - The user has elected cancel changes.
        Called before the dialog returns gtk.RESPONSE_CANCEL for run()
        """

        #restore any changes to self.__preferences here
        pass

def NewBuscaPreferencesDialog():
    """NewPreferencesFindfilesDialog - returns a fully instantiated
    PreferencesFindfilesDialog object. Use this function rather than
    creating a PreferencesFindfilesDialog instance directly.
    """

    #look for the ui file that describes the ui
    ui_filename = os.path.join(getdatapath(), 'ui', 'BuscaPreferencesDialog.ui')
    if not os.path.exists(ui_filename):
        ui_filename = None

    builder = gtk.Builder()
    builder.add_from_file(ui_filename)
    dialog = builder.get_object("busca_preferences_dialog")
    dialog.finish_initializing(builder)
    return dialog

if __name__ == "__main__":
    dialog = NewPreferencesBuscaDialog()
    dialog.show()
    gtk.main()

