# -*- coding: utf-8 -*-
### BEGIN LICENSE
# Busca: Full featured file searching application
# Copyright (C) 2009 Jordi Carrillo Bosch
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

### END LICENSE

import sys
import os
import gtk

from busca.buscaconfig import getdatapath
from busca import buscaconst

class DeleteFileDialog(gtk.Dialog):
    __gtype_name__ = "DeleteFileDialog"

    def __init__(self):
        """__init__ - This function is typically not called directly.
        Creation of a AboutFindfilesDialog requires redeading the associated ui
        file and parsing the ui definition extrenally, 
        and then calling AboutFindfilesDialog.finish_initializing().
    
        Use the convenience function NewAboutFindfilesDialog to create 
        NewAboutFindfilesDialog objects.
    
        """
        pass
    def finish_initializing(self, builder):
        """finish_initalizing should be called after parsing the ui definition
        and creating a AboutFindfilesDialog object with it in order to finish
        initializing the start of the new AboutFindfilesDialog instance.
    
        """
        #get a reference to the builder and set up the signals
        self.builder = builder
        self.builder.connect_signals(self)
        self.lblFileToDelete = builder.get_object('lblFileToDelete')

    def on_btnYes_clicked(self, widget):
        return self.response(gtk.RESPONSE_YES)

    def on_btnNo_clicked(self, widget):
        return self.response(gtk.RESPONSE_NO)
    

    @property
    def fileToDelete(self):
        return self.lblFileToDelete.get_text()

    @fileToDelete.setter
    def fileToDelete(self, filepathiters):
        # filepathiters is a list of 2-tuples (filepath,iter)
        curtext = ''
        if len(filepathiters) > 1:
            return
        file, iter = filepathiters[0]
        self.lblFileToDelete.set_text(file)


def NewDeleteFileDialog():
    """NewAboutFindfilesDialog - returns a fully instantiated
    AboutFindfilesDialog object. Use this function rather than
    creating a AboutFindfilesDialog instance directly.
    
    """

    #look for the ui file that describes the ui
    ui_filename = os.path.join(getdatapath(), 'ui', 'DeleteFileDialog.ui')
    if not os.path.exists(ui_filename):
        ui_filename = None

    builder = gtk.Builder()
    builder.add_from_file(ui_filename)    
    dialog = builder.get_object("deleteFileDialog")
    dialog.finish_initializing(builder)
    return dialog

if __name__ == "__main__":
    dialog = NewDeleteFileDialog()
    dialog.show()
    gtk.main()

