# -*- coding: utf-8 -*-
### BEGIN LICENSE
# Busca: Full featured file searching application
# Copyright (C) 2009 Jordi Carrillo Bosch
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

### END LICENSE

import sys
import os
import gtk
import datetime
from stat import *
import mimetypes

from busca.buscaconfig import getdatapath
from busca.buscaconst import *
from busca.filepool import convert_bytes, foundFilesPool

class InfoFileWindow(gtk.Window):
    __gtype_name__ = "InfoFileWindow"

    def __init__(self):
        """__init__ - This function is typically not called directly.
        Creation of a AboutFindfilesDialog requires redeading the associated ui
        file and parsing the ui definition extrenally, 
        and then calling AboutFindfilesDialog.finish_initializing().
    
        Use the convenience function NewAboutFindfilesDialog to create 
        NewAboutFindfilesDialog objects.
    
        """
        pass

    def finish_initializing(self, builder):
        """finish_initalizing should be called after parsing the ui definition
        and creating a AboutFindfilesDialog object with it in order to finish
        initializing the start of the new AboutFindfilesDialog instance.
    
        """
        #get a reference to the builder and set up the signals
        self.builder = builder
        self.lblFileName = builder.get_object('lblFileName')
        self.lblDirFile = builder.get_object('lblDirFile')
        self.lblFilePath = builder.get_object('lblFilePath')
        self.lblMimeType = builder.get_object('lblMimeType')
        self.lblFileEncoding = builder.get_object('lblFileEncoding')
        self.lblFileSize = builder.get_object('lblFileSize')
        self.lblFileModTime = builder.get_object('lblFileModTime')
        self.builder.connect_signals(self)

        #code for other initialization actions should be added here


    def setFileInfo(self, filepaths):
        '''populates the info window, 
        filepaths is a list that in this 
        case will have just one element'''
        curfile = filepaths[0]
        fileProps = foundFilesPool.popFound(curfile)
        if not fileProps:
            return
        filepath = fileProps[FILEPATH]
        dirfile = fileProps[DIRFILE]
        filename = fileProps[FILENAME]
        fileType = fileProps[FILETYPE]
        fileEncoding = fileProps[FILEENCODING]
        filesize = fileProps[FILESIZE]
        curdate = fileProps[CURDATE]
        self.lblDirFile.set_text(dirfile)
        self.lblFileName.set_text(filename)
        self.lblFilePath.set_text(filepath)
        self.lblMimeType.set_text(fileType)
        self.lblFileEncoding.set_text(fileEncoding)
        self.lblFileSize.set_text(convert_bytes(filesize))
        self.lblFileModTime.set_text(curdate)

def NewInfoFileWindow():
    """NewAboutFindfilesDialog - returns a fully instantiated
    AboutFindfilesDialog object. Use this function rather than
    creating a AboutFindfilesDialog instance directly.
    
    """
    #look for the ui file that describes the ui
    ui_filename = os.path.join(getdatapath(), 'ui', 'InfoFileWindow.ui')
    if not os.path.exists(ui_filename):
        ui_filename = None

    builder = gtk.Builder()
    builder.add_from_file(ui_filename)    
    window = builder.get_object("infoWindow")
    window.finish_initializing(builder)
    window.set_position(gtk.WIN_POS_CENTER)
    return window

if __name__ == "__main__":
    window = NewInfoFileWindow()
    window.show()
    gtk.main()

