# -*- coding: utf-8 -*-
### BEGIN LICENSE
# Busca: Full featured file searching application
# Copyright (C) 2009 Jordi Carrillo Bosch
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

### END LICENSE

from __future__ import division
import sys
import os
import gtk
import datetime
from stat import *
import mimetypes

from busca.buscaconfig import getdatapath
from busca.buscaconst import *
from busca.filepool import convert_bytes, foundFilesPool

class SearchReportWindow(gtk.Window):
    __gtype_name__ = "SearchReportWindow"

    def __init__(self):
        """__init__ - This function is typically not called directly.
        Creation of a AboutFindfilesDialog requires redeading the associated ui
        file and parsing the ui definition extrenally, 
        and then calling AboutFindfilesDialog.finish_initializing().
    
        Use the convenience function NewAboutFindfilesDialog to create 
        NewAboutFindfilesDialog objects.
    
        """
        pass

    def finish_initializing(self, builder):
        """finish_initalizing should be called after parsing the ui definition
        and creating a AboutFindfilesDialog object with it in order to finish
        initializing the start of the new AboutFindfilesDialog instance.
    
        """
        #get a reference to the builder and set up the signals
        self.builder = builder
        self.lblSearchedFromDir = builder.get_object('lblSearchedFromDir')
        self.lblHomeDirectory = builder.get_object('lblHomeDirectory')
        self.lblSizeHomeDir = builder.get_object('lblSizeHomeDir')
        self.lblNumFilesFound = builder.get_object('lblNumFilesFound')
        self.lblOverallSize = builder.get_object('lblOverallSize')
        self.lblBiggestFile = builder.get_object('lblBiggestFile')
        self.lblRatioSizeHome = builder.get_object('lblRatioSizeHome')
        self.txtViewDuplicated = builder.get_object('txtViewDuplicated')
        self.txtBuffer = gtk.TextBuffer()
        self.txtViewDuplicated.set_buffer(self.txtBuffer)
        self.builder.connect_signals(self)

        #code for other initialization actions should be added here


    def report(self, reportDuplicateds):
        if foundFilesPool.numFilesFound == 0:
            return
        numFilesFound = foundFilesPool.numFilesFound
        overallSize = foundFilesPool.overallSize
        biggestOne = foundFilesPool.largest
        fh = os.popen('du -bs '+ HOME)
        SIZEHOME = fh.readline().split('\t')[0]
        fh.close()
        self.lblSearchedFromDir.set_text(foundFilesPool.dirFrom)
        self.lblHomeDirectory.set_text(HOME)
        self.lblSizeHomeDir.set_text(convert_bytes(int(SIZEHOME)))
        self.lblNumFilesFound.set_text(str(numFilesFound))
        self.lblOverallSize.set_text(convert_bytes(overallSize))
        self.lblBiggestFile.set_text(biggestOne)
        ratio = overallSize / int(SIZEHOME)
        self.lblRatioSizeHome.set_text(str(ratio))
        if reportDuplicateds:
            duplicateds = foundFilesPool.searchMatches()
            for i in duplicateds:
                self.txtBuffer.insert_at_cursor(str(i)+'\n')

def NewSearchReportWindow():
    """NewAboutFindfilesDialog - returns a fully instantiated
    AboutFindfilesDialog object. Use this function rather than
    creating a AboutFindfilesDialog instance directly.
    
    """
    #look for the ui file that describes the ui
    ui_filename = os.path.join(getdatapath(), 'ui', 'SearchReportWindow.ui')
    if not os.path.exists(ui_filename):
        ui_filename = None

    builder = gtk.Builder()
    builder.add_from_file(ui_filename)    
    window = builder.get_object("searchReportWindow")
    window.finish_initializing(builder)
    window.set_position(gtk.WIN_POS_CENTER)
    return window

if __name__ == "__main__":
    window = NewInfoFileWindow()
    window.show()
    gtk.main()

