# -*- coding: utf-8 -*-
### BEGIN LICENSE
# Busca: Full featured file searching application
# Copyright (C) 2009 Jordi Carrillo Bosch
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

### END LICENSE

import sys
import os
import gtk
import datetime
from stat import *
import mimetypes
import pprint
from busca.buscaconfig import getdatapath
from busca.buscaconst import *
from busca.filepool import (convert_bytes, 
                      foundFilesPool, 
                      largest,
                      amountSize)

class SelectedFilesInfoWindow(gtk.Window):
    __gtype_name__ = "SelectedFilesInfoWindow"

    def __init__(self):
        """__init__ - This function is typically not called directly.
        Creation of a AboutFindfilesDialog requires redeading the associated ui
        file and parsing the ui definition extrenally, 
        and then calling AboutFindfilesDialog.finish_initializing().
    
        Use the convenience function NewAboutFindfilesDialog to create 
        NewAboutFindfilesDialog objects.
    
        """
        pass

    def finish_initializing(self, builder):
        """finish_initalizing should be called after parsing the ui definition
        and creating a AboutFindfilesDialog object with it in order to finish
        initializing the start of the new AboutFindfilesDialog instance.
    
        """
        #get a reference to the builder and set up the signals
        self.builder = builder
        self.lblLargestFile = builder.get_object('lblLargestFile')
        self.lblOverallSize = builder.get_object('lblOverallSize')
        self.lblNumSelectedFiles = builder.get_object('lblNumSelectedFiles')
        self.builder.connect_signals(self)

        #code for other initialization actions should be added here


    def setFileInfo(self, filepaths):
        numFilesSelected = len(filepaths)
        numTotalFiles = len(foundFilesPool.filePool)
        selectedFiles = {}
        for fullpathfile in filepaths:
            selectedFiles[fullpathfile] = foundFilesPool.popFound(fullpathfile)
        largestFile = largest(selectedFiles)
        overAllSize = convert_bytes(amountSize(selectedFiles))

        txtNumSelected = str(numFilesSelected) + ' out of '+ str(numTotalFiles)
        self.lblNumSelectedFiles.set_text(txtNumSelected)
        self.lblOverallSize.set_text(overAllSize)
        self.lblLargestFile.set_text(largestFile)

       
def NewSelectedFilesInfoWindow():
    """NewAboutFindfilesDialog - returns a fully instantiated
    AboutFindfilesDialog object. Use this function rather than
    creating a AboutFindfilesDialog instance directly.
    
    """
    #look for the ui file that describes the ui
    ui_filename = os.path.join(getdatapath(), 'ui', 'SelectedFilesInfoWindow.ui')
    if not os.path.exists(ui_filename):
        ui_filename = None

    builder = gtk.Builder()
    builder.add_from_file(ui_filename)    
    window = builder.get_object("SelectedFilesInfoWindow")
    window.finish_initializing(builder)
    window.set_position(gtk.WIN_POS_CENTER)
    return window

if __name__ == "__main__":
    window = NewSelectedFilesInfoWindow()
    window.show()
    gtk.main()

