### BEGIN LICENSE
# Busca: Full featured file searching application
# Copyright (C) 2009 Jordi Carrillo Bosch
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

### END LICENSE


# Module that holds the information 
# about all found files

import os
import gtk
import logging
from stat import *
import mimetypes
import difflib
import datetime
from busca.buscaconst import *
from operator import itemgetter

def convert_bytes(bytes):
    # code from http://www.5dollarwhitebox.org/drupal/node/84
        bytes = float(bytes)
        if bytes >= 1099511627776:
            terabytes = bytes / 1099511627776
            size = '%.2fT' % terabytes
        elif bytes >= 1073741824:
            gigabytes = bytes / 1073741824
            size = '%.2fG' % gigabytes
        elif bytes >= 1048576:
            megabytes = bytes / 1048576
            size = '%.2fM' % megabytes
        elif bytes >= 1024:
            kilobytes = bytes / 1024
            size = '%.2fK' % kilobytes
        else:
            size = '%.2fb' % bytes
        return size


def getTupleSizes(files):
    '''returns a list of tuples 
    where first element fullpathfile 
    and second its size'''

    return [(k[0],k[1][FILESIZE]) for k in files.items()]

def getTupleFileNames(files):
    return [(k[0],k[1][FILENAME]) for k in files.items()]

def getFileNames(files):
    return [k[1][FILENAME] for k in files.items()]

            
def largest(files):
    '''
    returns the largest file in 
    a collection of files, where collection 
    is a dictionary where keys are full path to those 
    files and values is a dictionary with their
    properties
    
    files = Dictionary of fullfile = {properties}
    '''
    filesizes = getTupleSizes(files)
    largest = sorted(dict(filesizes).items(), key = itemgetter(1),
                    reverse = True)
    return largest[0][0]

def amountSize(files):
    ''' 
    returns the sum of all sizes in 
    the files dictionary
    '''
    filesizes = getTupleSizes(files)
    amounts = [ k[1] for k in filesizes ]
    curamount = 0
    for j in amounts:
        curamount += j
    return curamount


class FilePool:
        def __init__(self):
            self.__foundFiles = {}
            self.__dirFrom = ''
            self.__fileNames = []
            self.prgBar = None
            self.logger = logging.getLogger('filepool')

        @property
        def dirFrom(self):
            return __dirFrom
        
        @dirFrom.setter
        def dirFrom(self, dirFrom):
            self.__dirFrom = dirFrom

        @property
        def filePool(self):
            return self.__foundFiles
        
        @property
        def overallSize(self):
            return amountSize(self.__foundFiles)

        @property
        def numFilesFound(self):
            return len(self.__foundFiles)


        @property
        def largest(self):
            return largest(self.__foundFiles)

        def pushFound(self, filepath):
            if filepath not in self.__foundFiles:
                dirfile = os.path.dirname(filepath)
                filename = os.path.basename(filepath)
                self.__fileNames.append(filename)
                fileType, fileEncoding = mimetypes.guess_type(filename)
                if not fileType:
                    fileType = ''
                if not fileEncoding:
                    fileEncoding = ''
                filesize = os.stat(filepath)[ST_SIZE]
                filemodetime = os.stat(filepath)[ST_CTIME]
                curdate = datetime.datetime.fromtimestamp(filemodetime)
                
                self.__foundFiles[filepath] = {}
                thisfile = self.__foundFiles[filepath]
                thisfile[FILEPATH] = filepath
                thisfile[DIRFILE] = dirfile
                thisfile[FILENAME] = filename
                thisfile[FILETYPE] = fileType
                thisfile[FILEENCODING] = fileEncoding
                thisfile[FILESIZE] = filesize
                thisfile[FILEMODTIME] = filemodetime
                thisfile[CURDATE] = curdate.isoformat(' ')
        
        def popFound(self, filepath):
            if filepath in self.__foundFiles:
                return self.__foundFiles[filepath]
            return None

        #def searchMatches(self):
            #filePathNames = getTupleFileNames(self.__foundFiles)
            #matches = []
            #foundFiles = self.__foundFiles.copy()
            #for filename in filePathNames:
                #fullpath = filename[0]
                #justname = filename[1]
                ## remove current file from foundFiles
                #del(foundFiles[fullpath])
                #curFiles = getFileNames(foundFiles)
                #closerOnes = difflib.get_close_matches(justname,
                        #curFiles, 1)
                #print closerOnes
                #for one in closerOnes:
                    ## get fullpath of matched ones

                    #matches.append(one)
            #return matches
        
        def searchMatches(self):
            filePathNames = getTupleFileNames(self.__foundFiles)
            matches = []
            foundFiles = self.__foundFiles.copy()
            for filename in filePathNames:
                fullpath = filename[0]
                justname = filename[1]
                # remove current file from foundFiles
                del(foundFiles[fullpath])
                curFiles = getFileNames(foundFiles)
                self.logger.debug("justname [%s]" % justname)
                self.logger.debug("curfiles [%s]" % curFiles)
                closerOnes = difflib.get_close_matches(justname,
                        curFiles, 1, 1)
                self.prgBar.pulse()
                while gtk.events_pending():
                    gtk.main_iteration(False)

                
                self.logger.debug("closerOnes [%s]" % closerOnes)
                for one in closerOnes:
                    # get fullpath of matched ones
                    for tup in filePathNames:
                        if tup[1] == one and fullpath != tup[0]:
                            matches.append((fullpath,tup[0]))
            self.prgBar.set_fraction(0)
            return matches

        def setPrgBar(self, prgBar):
            self.prgBar = prgBar

        def reset(self):
            self.__foundFiles = {}


foundFilesPool = FilePool()
