#!/usr/bin/env python
# -*- coding: utf-8 -*-
### BEGIN LICENSE
# Busca: Full featured file searching application
# Copyright (C) 2009 Jordi Carrillo Bosch
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

### END LICENSE


from distutils.core import Command

try:
    import DistUtilsExtra.auto
except ImportError:
    import sys
    print >> sys.stderr, 'To build busca you need https://launchpad.net/python-distutils-extra'
    sys.exit(1)

assert DistUtilsExtra.auto.__version__ >= '2.10', 'needs DistUtilsExtra.auto >= 2.10'
import os


def update_data_path(prefix, oldvalue=None):

    try:
        fin = file('busca/buscaconfig.py', 'r')
        fout = file(fin.name + '.new', 'w')

        for line in fin:            
            fields = line.split(' = ') # Separate variable from value
            if fields[0] == '__busca_data_directory__':
                # update to prefix, store oldvalue
                if not oldvalue:
                    oldvalue = fields[1]
                    line = "%s = '%s'\n" % (fields[0], prefix)
                else: # restore oldvalue
                    line = "%s = %s" % (fields[0], oldvalue)
            fout.write(line)

        fout.flush()
        fout.close()
        fin.close()
        os.rename(fout.name, fin.name)
    except (OSError, IOError), e:
        print ("ERROR: Can't find busca/buscaconfig.py")
        sys.exit(1)
    return oldvalue


def update_desktop_file(datadir):

    try:
        fin = file('busca.desktop.in', 'r')
        fout = file(fin.name + '.new', 'w')

        for line in fin:            
            if 'Icon=' in line:
                line = "Icon=%s\n" % (datadir + 'media/icon.png')
            fout.write(line)
        fout.flush()
        fout.close()
        fin.close()
        os.rename(fout.name, fin.name)
    except (OSError, IOError), e:
        print ("ERROR: Can't find busca.desktop.in")
        sys.exit(1)


class InstallAndUpdateDataDirectory(DistUtilsExtra.auto.install_auto):
    def run(self):
        if self.root or self.home:
            print "WARNING: You don't use a standard --prefix installation, take care that you eventually " \
            "need to update quickly/quicklyconfig.py file to adjust __quickly_data_directory__. You can " \
            "ignore this warning if you are packaging and uses --prefix."
        previous_value = update_data_path(self.prefix + '/share/busca/')
        update_desktop_file(self.prefix + '/share/busca/')
        DistUtilsExtra.auto.install_auto.run(self)
        update_data_path(self.prefix, previous_value)

class Clean(Command):
    user_options = []
    
    def initialize_options(self):
        self.__toRemove = []
        for root,path,files in os.walk("."):
            for file in files:
                if file.endswith(('~','pyc','#')):
                    self.__toRemove.append(os.path.join(root,file))
    
    def finalize_options(self):
        pass
    
    def run(self):
        curdir = os.getcwd()
        distdir = pjoin(curdir,"dist")
        if os.path.exists(distdir):
            print "removing distribution directory"
            shutil.rmtree(distdir)
        
        manifest = pjoin(curdir,'MANIFEST')
        if os.path.exists(manifest):
            print "removing MANIFEST file"
            os.unlink(manifest)

        for file in self.__toRemove:
            try:
                print "removing "+file
                os.unlink(file)
            except:
                pass


DistUtilsExtra.auto.setup(
    name = 'busca',
    version = '0.4',
    license = 'GPL v3',
    author = 'Jordi Carrillo',
    author_email = 'jordilin@gmail.com',
    description = 'Full featured file searching application',
    long_description = 'Busca is similar to the search tool in Gnome, but it will implement additional features to manage efficiently your files in a fast and easy way. It gives information of every single file found and allows you to sort by size and filename. As of now, it allows you to delete the files you select as well.', 
    url = 'https://launchpad.net/busca',
    cmdclass = {'install': InstallAndUpdateDataDirectory,
                'clean' : Clean}
    )

