# Busca: A linear file extension and regex file searcher
# Copyright (C) 2009 Jordi Carrillo Bosch
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


import unittest
import os, sys
from tempfile import *

sys.path.append('..')
from busca.filepool import foundFilesPool

TESTFILE = 'test.tmp'
TESTFILE2 = 'test2.tmp'

class TestFilePool(unittest.TestCase):
    
    def setUp(self):
        fh = open('test.tmp','w')
        fh.write('testing filepool')
        fh.close()
        
        fh2 = open(TESTFILE2, 'w')
        fh2.write('test')
        fh2.close()
    
    def populateFound(self):
        filepath = os.path.join(os.path.dirname(TESTFILE),TESTFILE)
        foundFilesPool.pushFound(filepath)
        filepath = os.path.join(os.path.dirname(TESTFILE2),TESTFILE2)
        foundFilesPool.pushFound(filepath)

    def testShouldInstantiateFilePool(self):
        filepath = os.path.join(os.path.dirname(TESTFILE),TESTFILE)
        foundFilesPool.pushFound(filepath)
        fileprops = foundFilesPool.popFound(filepath)
        if not fileprops:
            self.fail()
        filename = fileprops['filename']
        self.assertEqual(filename, TESTFILE)

    def testShouldGiveTheBiggestFileFound(self):
        filepath = os.path.join(os.path.dirname(TESTFILE2),TESTFILE2)
        foundFilesPool.pushFound(filepath)
        self.assertEqual(1, foundFilesPool.numFilesFound)
        filepath = os.path.join(os.path.dirname(TESTFILE),TESTFILE)
        foundFilesPool.pushFound(filepath)
        self.assertEqual(2, foundFilesPool.numFilesFound)
        self.assertEqual(TESTFILE, foundFilesPool.largest)
    
    def testShouldGiveBestMatchPossibleifItDoesExist(self):
        self.assertEqual(0, foundFilesPool.numFilesFound)       
        self.populateFound()
        self.assertEqual(2, foundFilesPool.numFilesFound)
        foundFilesPool.setPrgBar(ProgrBar())
        gotmatches = foundFilesPool.searchMatches()
        self.assertEquals(0, len(gotmatches))


    def tearDown(self):
        if os.path.exists(TESTFILE):
            os.remove(TESTFILE)
        if os.path.exists(TESTFILE2):
            os.remove(TESTFILE2)
        foundFilesPool.reset()

class ProgrBar:
    def __init__(self):
        pass
    def pulse(self):
        pass
    def set_fraction(self, val):
        pass
